==> scikit-criteria-0.2.tar.gz: scikit-criteria-0.2/skcriteria/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2016-2017, Cabral, Juan; Luczywo, Nadia
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# * Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.

# * Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.

# * Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


# =============================================================================
# FUTURE
# =============================================================================

from __future__ import unicode_literals


# =============================================================================
# DOCS
# =============================================================================

__doc__ = """Scikit-Criteria is a collections of algorithms, methods and
techniques for multiple-criteria decision analysis [].

"""

# =============================================================================
# CONSTANTS
# =============================================================================

__version__ = ("0", "2")

NAME = "scikit-criteria"

DOC = __doc__

VERSION = ".".join(__version__)

AUTHORS = "Cabral & Luczywo"

EMAIL = "jbc.develop@gmail.com"

URL = "http://scikit-criteria.org/"

LICENSE = "3 Clause BSD"

KEYWORDS = "mcda mcdm ahp moora muti criteria".split()

# =============================================================================
# IMPORTS
# =============================================================================

import os

if os.getenv("SKCRITERIA_IN_SETUP") != "True":
    from .dmaker import Data  # noqa
    from .util import MAX, MIN  # noqa

del os

# =============================================================================
# MAIN
# =============================================================================

if __name__ == "__main__":
    print(__doc__)

==> scikit-criteria-0.2.1.tar.gz: scikit-criteria-0.2.1/skcriteria/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2016-2017, Cabral, Juan; Luczywo, Nadia
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# * Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.

# * Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.

# * Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


# =============================================================================
# FUTURE
# =============================================================================

from __future__ import unicode_literals


# =============================================================================
# DOCS
# =============================================================================

__doc__ = """Scikit-Criteria is a collections of algorithms, methods and
techniques for multiple-criteria decision analysis [].

"""

# =============================================================================
# CONSTANTS
# =============================================================================

__version__ = ("0", "2", "1")

NAME = "scikit-criteria"

DOC = __doc__

VERSION = ".".join(__version__)

AUTHORS = "Cabral & Luczywo"

EMAIL = "jbc.develop@gmail.com"

URL = "http://scikit-criteria.org/"

LICENSE = "3 Clause BSD"

KEYWORDS = "mcda mcdm ahp moora muti criteria".split()

# =============================================================================
# IMPORTS
# =============================================================================

import os

if os.getenv("SKCRITERIA_IN_SETUP") != "True":
    from .dmaker import Data  # noqa
    from .util import MAX, MIN  # noqa

del os

# =============================================================================
# MAIN
# =============================================================================

if __name__ == "__main__":
    print(__doc__)
